==========================================
 Migrating to a new version of RelStorage
==========================================

Sometimes RelStorage needs a schema modification along with a software
upgrade.  Hopefully, this will not often be necessary.

.. toctree::
   :maxdepth: 1

   migration/migrate-to-3.0
   migration/migrate-to-1.5
   migration/migrate-to-1.4
   migration/migrate-to-1.1.2
   migration/migrate-to-1.1.1
   migration/migrate-to-1.1
   migration/migrate-to-1.0
